﻿let componentObj;
let grid;
let employeeStore;
let employeePickerStore;
let employeeCombo;

var programsAndPhases = null;
var phases = null;

var BlankLabelFilter1 = '(Unassigned / Blank)';

var SWPgridFunctions = {

    loadStaticResources : async() => {

        //--- Add Bryntum Grid scripts and css...

        var AddBryntumGrid = true;

        if (typeof bryntum != 'undefined') {
            if (typeof bryntum.grid != 'undefined') AddBryntumGrid = false;
        }

        if (AddBryntumGrid) await $.getScript('../../build/grid.umd.js');
    },

    displayBryntumHcGrid : async function(gridSourceData, isReadonly) {

        console.log(gridSourceData);

        const rowDataStore = new bryntum.grid.Store({
            tree                     : true,
            autoCommit               : true,
            data                     : gridSourceData.namesInFrames,
            convertEmptyParentToLeaf : false,
            fields                   : [
                { name : 'locationId', type : 'integer' },
                { name : 'locationName', type : 'string' },
                { name : 'groupId', type : 'integer' },
                { name : 'groupName', type : 'string' },

                { name : 'treeColumnName', type : 'string' },
                { name : 'sqlId', type : 'integer' },

                { name : 'employeeId', type : 'integer' },
                { name : 'positionId', type : 'integer' },
                { name : 'assignmentStart', type : 'date' },
                { name : 'assignmentEnd', type : 'date' },
                { name : 'phaseStart', type : 'integer' },
                { name : 'phaseEnd', type : 'integer' },
                { name : 'percentFte', type : 'integer' },
                { name : 'notes', type : 'string' },
                { name : 'expOrCapId', type : 'integer' },
                { name : 'Relocated', type : 'string' },
                { name : 'Status', type : 'string' },
                { name : 'modelId', type : 'integer' }
            ]

        });

        employeeStore = new bryntum.grid.Store({
            autoCommit : false,
            fields     : [
                { name : 'id', type : 'integer' },
                { name : 'wwid', type : 'integer' },
                { name : 'fullName', type : 'string' },
                { name : 'managerWwid', type : 'integer' },
                { name : 'costCenter', type : 'string' },
                { name : 'homeSite', type : 'string' },
                { name : 'employeeType', type : 'string' },
                { name : 'team', type : 'string' },
                { name : 'teamId', type : 'integer' }
            ],
            data      : gridSourceData.employees,
            listeners : {
                beforeCommit(event) {
                },
                commit(event) {
                    grid.refreshRows();
                }
            }
        });

        const expCapStore = new bryntum.grid.Store({
            data : gridSourceData.expCapDropdowns
        });

        const positionStore = new bryntum.grid.Store({
            data : gridSourceData.positionDropdowns
        });

        const teamStore = new bryntum.grid.Store({
            autoCommit : true,
            data       : gridSourceData.teamDropdowns
        });

        employeePickerStore = new bryntum.grid.Store({
            fields : [
                { name : 'wwid', type : 'integer' },
                { name : 'fullName', type : 'string' },
                { name : 'managerWwid', type : 'integer' },
                { name : 'costCenter', type : 'string' },
                { name : 'homeSite', type : 'string' },
                { name : 'employeeType', type : 'string' },
                { name : 'team', type : 'string' }
            ]
        });

        var employeeCombo = new bryntum.grid.Combo({
            displayField   : 'fullName',
            valueField     : 'id',
            filterOperator : '*',
            filterOnEnter  : false,
            store          : employeePickerStore,
            clearable      : true,
            pickerWidth    : 300
        });

        const expCapCombo = new bryntum.grid.Combo({
            displayField : 'textValue',
            valueField   : 'id',
            store        : expCapStore
        });

        var positionCombo = new bryntum.grid.Combo({
            displayField : 'textValue',
            valueField   : 'id',
            store        : positionStore
        });

        var phasesStore = new bryntum.grid.Store({
            data : gridSourceData.phases.filter(f => f.isArchived == false)
        });

        var modelsStore = new bryntum.grid.Store({
            data   : gridSourceData.models,
            fields : [
                { name : 'id', type : 'integer' },
                { name : 'actionWhenFound', type : 'string' },
                { name : 'allowedPositionsCount', type : 'integer' },
                { name : 'description', type : 'string' },
                { name : 'startPhaseId', type : 'integer' },
                { name : 'endPhaseId', type : 'integer' },
                { name : 'groupId', type : 'integer' },
                { name : 'isFinalized', type : 'boolean' },
                { name : 'isTemplate', type : 'boolean' },
                { name : 'modelName', type : 'string' },
                { name : 'notes', type : 'string' },
                { name : 'populatedRowsCount', type : 'integer' },
                { name : 'teamSizePercent', type : 'integer' },
                { name : 'templateSourceId', type : 'integer' }
            ]
        });

        grid = new bryntum.grid.TreeGrid({
            store        : rowDataStore,
            appendTo     : 'gridContainer',
            autoHeight   : true,
            destroyStore : true,
            readOnly     : isReadonly,
            features     : {
                rowReorder : {
                    showGrip : true
                }

            },
            columns : [
                {
                    type     : 'tree',
                    text     : 'Location/Group/Position',
                    field    : 'treeColumnName',
                    minWidth : 200,
                    editor   : positionCombo
                    //    renderer(renderData) {

                    //        var record = renderData.record;

                    //        if (record.id.startsWith('Leaf')) {

                    //            if (renderData.value != '' && (!isNaN(renderData.value))) {
                    //                return positionStore.getById(renderData.value).textValue;
                    //            } else {

                    //                return {
                    //                    children: [
                    //                        {
                    //                            tag: 'span',
                    //                            html: `<span class="text-primary">Select position...</span>`,
                    //                        },
                    //                    ]
                    //                }
                    //            }

                    //        }

                    //        if (record.id.startsWith('Location')) {

                    //            if (record.children.length == 0) {

                    //                return {
                    //                    children: [
                    //                        {
                    //                            tag: 'span',
                    //                            html: `${renderData.value} <small span class="text-primary"><i>(Empty Location)</i></small>`,
                    //                        },
                    //                    ]
                    //                }
                    //            } else {
                    //                return {
                    //                    children: [
                    //                        {
                    //                            tag: 'span',
                    //                            html: `${renderData.value} <small span class="text-primary"><i>(${record.children.length} Groups)</i></small>`,
                    //                        },
                    //                    ]
                    //                }
                    //            }

                    //        }

                //        return renderData.value;
                //    },
                },
                {
                    text       : 'Employee',
                    field      : 'employeeId',
                    editor     : employeeCombo,
                    minWidth   : 170,
                    filterable : false,
                    cellMenu   : false
                },
                {
                    text   : 'Reloc',
                    field  : 'relocated',
                    width  : 70,
                    editor : new bryntum.grid.Combo({
                        items        : gridSourceData.relocationOptions,
                        valueField   : 'optionValue',
                        displayField : 'optionDesc',
                        multiSelect  : false,
                        pickerWidth  : 200
                    })
                },
                {
                    text   : 'Status',
                    field  : 'status',
                    width  : 70,
                    editor : new bryntum.grid.Combo({
                        items        : gridSourceData.statusOptions,
                        valueField   : 'optionValue',
                        displayField : 'optionDesc',
                        multiSelect  : false,
                        pickerWidth  : 200
                    })
                },
                { type : 'number', text : 'Row ID', field : 'id', hidden : true, editor : false },
                { text : '% FTE', field : 'percentFte', type : 'percent', width : '4em' },
                {
                    text : 'Employee<br/>Type', field : 'employeeId', width : '6em', htmlEncodeHeaderText : false, editor : false
                },
                {
                    text : 'Home<br/>Site', field : 'employeeId', editor : false, width : '4em', htmlEncodeHeaderText : false
                },

                {
                    text : 'Phase Period', field : 'phasePeriod', align : 'center', width : '8em', editor : false
                },

                { type : 'date', text : 'Assignment<br/>Start', field : 'assignmentStart', width : '6.5em', htmlEncodeHeaderText : false },
                { type : 'date', text : 'Assignment<br/>End', field : 'assignmentEnd', width : '6.5em', htmlEncodeHeaderText : false },

                {
                    text                 : '<div class="text-center">Phase<br/>Start</div>',
                    cellCls              : 'p-0',
                    htmlEncodeHeaderText : false,
                    type                 : 'widget',
                    minWidth             : 100,
                    widgets              : [
                        {
                            type         : 'combo',
                            multiSelect  : false,
                            store        : phasesStore,
                            valueField   : 'id',
                            displayField : 'textValue',
                            style        : '',
                            pickerWidth  : 200,
                            textAlign    : 'center'
                        }
                    ]
                },
                {
                    text                 : '<div class="text-center">Phase<br/>End</div>',
                    cellCls              : 'p-0',
                    htmlEncodeHeaderText : false,
                    type                 : 'widget',
                    minWidth             : 100,
                    widgets              : [
                        {
                            type         : 'combo',
                            multiSelect  : false,
                            store        : phasesStore,
                            valueField   : 'id',
                            displayField : 'textValue',
                            pickerWidth  : 200,
                            textAlign    : 'center'
                        }
                    ]
                },
                {
                    text : 'Comments / Notes', field : 'notes', flex : 1, minWidth : 200, htmlEncodeHeaderText : false, align : 'center'
                },
                {
                    text : 'Cost<br/>Center', field : 'employeeId', width : '4.5em', editor : false, htmlEncodeHeaderText : false
                },
                {
                    text : 'EXP/<br/>CAP', field : 'expOrCapId', width : '3em', editor : expCapCombo, htmlEncodeHeaderText : false
                },
                {
                    text     : 'Team',
                    align    : 'center',
                    type     : 'widget',
                    cellCls  : 'p-0',
                    minWidth : 150,
                    widgets  : [
                        {
                            type         : 'combo',
                            multiSelect  : false,
                            store        : teamStore,
                            valueField   : 'id',
                            displayField : 'textValue',
                            textAlign    : 'center'
                        }
                    ]
                },
                {
                    text : '<center><small>From</small><br>Model</center>', htmlEncodeHeaderText : false, minWidth : 150, editor : false, readOnly : true
                }
            ]

        });

    }

};
